#!/bin/bash
###########################################################################
### Purpose = Clone an existing linux template with cloud-init support. ###
###########################################################################

###############################################################################################
### IMPORTANT! Change the user password! After you have logged in to the new cloned server. ###
###############################################################################################

#########################################
### Change these variables as needed! ###
#########################################
TEMPLATE_VMID=1212
CLONE_VMID=501
CLONE_NAME=debian-12-test
STORAGE=ceph_ssd
SIZE=16G
MEMORY=2048
CORES=2
SOCKETS=1
CPU='host'
# MAC-address should either be blank or a valid MAC-adress in the format XX:XX:XX:XX:XX:XX.
MAC=
# IPV4-address should either be a valid IP-adress/CIDR, or it should be blank (which configure DHCP).
IPV4=
# If IPV4-address is set, then GWV4 should valid IP-adress for the gateway/router, or it should be blank (which configure DHCP).
GWV4=
# VLAN tag should either be blank or a valid VLAN.
VLAN_TAG=
# Change CI_USER to whatever username you would like to use.
CI_USER=poweruser
# Set the CI_USER Password. Remember to change the password! After you have logged in to the cloned server as the CI_USER with SSHKEYS.
CI_PASSWORD=passw0rd!
# Leave blank for no SSH-keys or set name of a file containing public SSH-keys that will be added as autorized-keys for the CI_USER.
# When SSHKEYS is set this then disables normal login to the server (by password, only publickey is accepted).
SSHKEYS=

###################################################################################
### Do NOT change anything below this line! Unless you know what you are doing. ###
###################################################################################
if [ "$USER" != "root" ]
then
    echo "Please run this script as root."
    exit 1
fi

START_TIME=`date +'%F %T %Z'`
echo ''
echo "Script started at $START_TIME."
echo ''

echo ''
echo "Clone the template to a new server called $CLONE_NAME with VMID=$CLONE_VMID"
echo '###########################################################################'
echo ''
qm clone $TEMPLATE_VMID $CLONE_VMID --full 1 --name $CLONE_NAME --storage $STORAGE
qm resize $CLONE_VMID scsi0 $SIZE
qm set $CLONE_VMID --memory $MEMORY --cores $CORES --sockets $SOCKETS --cpu $CPU
if [ -z "$VLAN_TAG" ]
  then
    if [ -z "$MAC" ]
      then 
        qm set $CLONE_VMID -net0 virtio,bridge=vmbr0,tag=$VLAN_TAG
      else
        qm set $CLONE_VMID -net0 virtio,bridge=vmbr0,macaddr=$MAC,tag=$VLAN_TAG
    fi
  else
    if [ -z "$MAC" ]
      then
        qm set $CLONE_VMID -net0 virtio,bridge=vmbr0
      else
        qm set $CLONE_VMID -net0 virtio,bridge=vmbr0,macaddr=$MAC
    fi
fi

if [ -z "$IPV4" ] && [ -z "GWV4" ]
  then
    qm set $CLONE_VMID --ipconfig0 ip=dhcp
  else
    qm set $CLONE_VMID --ipconfig0 gw=$GWV4,ip=$IPV4
fi
qm set $CLONE_VMID --ciuser $CI_USER --cipassword $CI_PASSWORD
if [ -n "SSHKEYS" ] && [ -e "SSHKEYS" ]
  then
    qm set $CLONE_VMID --sshkeys "$SSHKEYS"
fi


qm start $CLONE_VMID

echo ''
echo "server: $CLONE_NAME"
echo "vmid: $CLONE_VMID"
qm status $CLONE_VMID

STOP_TIME=`date +'%F %T %Z'`
echo ''
echo "Clone have been created! Script was ready at $STOP_TIME."
echo ''
exit 0